@@ -18,6 +18,8 @@ class Site(Site):
     url = SETUP_INFO['url']
     project_model = 'tickets.Site'
 
+    # use_elasticsearch = True
+
     demo_fixtures = ['std', 'minimal_ledger', 'demo', 'demo2', 'demo_bookings',
     'checksummaries']  # 'linotickets', 'tractickets', 'luc']
 
@@ -98,7 +100,7 @@ class Site(Site):
         yield 'lino_noi.lib.sales'
         yield 'lino_xl.lib.invoicing'
         yield 'lino_xl.lib.orders'
-        yield 'lino.modlib.elastic'
+        # yield 'lino.modlib.elastic'
 
     def get_plugin_configs(self):
         yield super(Site, self).get_plugin_configs()
