@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2020 Rumma & Ko Ltd
+# Copyright 2016-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Database models specific for Lino Noi.
@@ -13,6 +13,7 @@ from lino.modlib.users.mixins import Assignable
 from lino.modlib.summaries.mixins import Summarized
 from lino_xl.lib.tickets.models import *
 from lino_xl.lib.working.choicelists import ReportingTypes, ZERO_DURATION
+from lino.modlib.elastic.mixins import ElasticSearchable
 
 
 def get_summary_fields():
@@ -50,12 +51,14 @@ class Site(Site):
     #    rt.models.tickets.Subscription.objects.create(user=ar.get_user(), site=self)
 
 
-class Ticket(Ticket, Assignable, Summarized):
+class Ticket(Ticket, Assignable, Summarized, ElasticSearchable):
 
     class Meta(Ticket.Meta):
         # app_label = 'tickets'
         abstract = dd.is_abstract_model(__name__, 'Ticket')
 
+    ES_indexes = {('ticket',)}
+
     def assigned_to_changed(self, ar):
         """Add a star and send notification of Assignment"""
         # self.add_change_watcher(self.assigned_to)
